@@ -1,4 +1,4 @@
-# SPDX-FileCopyrightText: 2017-2021 Contributors to the OpenSTF project <korte.termijn.prognoses@alliander.com> # noqa E501>
+# SPDX-FileCopyrightText: 2017-2022 Contributors to the OpenSTEF project <korte.termijn.prognoses@alliander.com> # noqa E501>
 #
 # SPDX-License-Identifier: MPL-2.0
 from abc import ABC, abstractmethod
@@ -13,7 +13,7 @@ from openstef.feature_engineering.general import (
     enforce_feature_order,
     remove_non_requested_feature_columns,
 )
-from openstef_dbc.services.prediction_job import PredictionJobDataClass
+from openstef.data_classes.prediction_job import PredictionJobDataClass
 
 LATENCY_CONFIG = {"APX": 24}  # A specific latency is part of a specific feature.
 
@@ -25,7 +25,7 @@ class AbstractFeatureApplicator(ABC):
         """Initialize abstract feature applicator.
 
         Args:
-            horizons (list): list of horizons
+            horizons (list): list of horizons in hours
             feature_names (List[str]):  List of requested features
         """
         if type(horizons) is not list and not None:
