@@ -1,4 +1,4 @@
-# SPDX-FileCopyrightText: 2017-2021 Contributors to the OpenSTF project <korte.termijn.prognoses@alliander.com> # noqa E501>
+# SPDX-FileCopyrightText: 2017-2022 Contributors to the OpenSTEF project <korte.termijn.prognoses@alliander.com> # noqa E501>
 #
 # SPDX-License-Identifier: MPL-2.0
 import logging
@@ -7,7 +7,7 @@ from typing import List, Tuple, Union
 
 import pandas as pd
 import structlog
-from openstef_dbc.services.prediction_job import PredictionJobDataClass
+from openstef.data_classes.prediction_job import PredictionJobDataClass
 
 from openstef.data_classes.model_specifications import ModelSpecificationDataClass
 from openstef.exceptions import (
@@ -244,13 +244,7 @@ def train_pipeline_common(
         ].sort_index()
 
     # Split data
-    (
-        peaks,
-        peaks_val_train,
-        train_data,
-        validation_data,
-        test_data,
-    ) = split_data_train_validation_test(
+    (train_data, validation_data, test_data,) = split_data_train_validation_test(
         data_with_features,
         test_fraction=test_fraction,
         stratification_min_max=stratification_min_max,
@@ -285,10 +279,12 @@ def train_pipeline_common(
     eval_set = [(train_x, train_y), (validation_x, validation_y)]
 
     # Set relevant hyperparameters
+    # define protected hyperparams which are derived from prediction_job
+    protected_hyperparams = ["quantiles"]
     valid_hyper_parameters = {
         key: value
         for key, value in modelspecs.hyper_params.items()
-        if key in model.get_params().keys()
+        if key in model.get_params().keys() and key not in protected_hyperparams
     }
 
     model.set_params(**valid_hyper_parameters)
